@@ -35,16 +35,18 @@
 #ifndef QMLDESIGNER_TEST
 #include <qmldesignerplugin.h>
 #include <viewmanager.h>
+#include <nodeabstractproperty.h>
 #endif
 
 #include <coreplugin/helpmanager.h>
 #include <utils/qtcassert.h>
+#include <utils/algorithm.h>
 
-#include <QRegExp>
+#include <QWidget>
+#include <QtGui/qimage.h>
 
 namespace QmlDesigner {
 
-
 /*!
 \class QmlDesigner::AbstractView
 \ingroup CoreModel
@@ -99,7 +101,7 @@ ModelNode AbstractView::createModelNode(const TypeName &typeName,
     Returns the constant root model node.
 */
 
-const ModelNode AbstractView::rootModelNode() const
+ModelNode AbstractView::rootModelNode() const
 {
     Q_ASSERT(model());
     return ModelNode(model()->d->rootNode(), model(), const_cast<AbstractView*>(this));
@@ -167,6 +169,9 @@ The default implementation is setting the reference of the model to the view.
 void AbstractView::modelAttached(Model *model)
 {
     setModel(model);
+
+    if (model)
+        model->d->updateEnabledViews();
 }
 
 /*!
@@ -264,8 +269,11 @@ void AbstractView::fileUrlChanged(const QUrl &/*oldUrl*/, const QUrl &/*newUrl*/
 {
 }
 
-void AbstractView::nodeOrderChanged(const NodeListProperty &/*listProperty*/, const ModelNode &/*movedNode*/, int /*oldIndex*/)
+void AbstractView::nodeOrderChanged(const NodeListProperty & /*listProperty*/) {}
+
+void AbstractView::nodeOrderChanged(const NodeListProperty &listProperty, const ModelNode &, int)
 {
+    nodeOrderChanged(listProperty);
 }
 
 /*!
@@ -323,6 +331,8 @@ void AbstractView::variantPropertiesChanged(const QList<VariantProperty>& /*prop
 {
 }
 
+void AbstractView::bindingPropertiesAboutToBeChanged(const QList<BindingProperty> &) {}
+
 void AbstractView::bindingPropertiesChanged(const QList<BindingProperty>& /*propertyList*/, PropertyChangeFlags /*propertyChange*/)
 {
 }
@@ -344,6 +354,14 @@ void AbstractView::importsChanged(const QList<Import> &/*addedImports*/, const Q
 {
 }
 
+void AbstractView::possibleImportsChanged(const QList<Import> &/*possibleImports*/)
+{
+}
+
+void AbstractView::usedImportsChanged(const QList<Import> &/*usedImports*/)
+{
+}
+
 void AbstractView::auxiliaryDataChanged(const ModelNode &/*node*/, const PropertyName &/*name*/, const QVariant &/*data*/)
 {
 }
@@ -362,9 +380,27 @@ void AbstractView::documentMessagesChanged(const QList<DocumentMessage> &/*error
 
 void AbstractView::currentTimelineChanged(const ModelNode & /*node*/)
 {
-
 }
 
+void AbstractView::renderImage3DChanged(const QImage & /*image*/)
+{
+}
+
+void AbstractView::updateActiveScene3D(const QVariantMap & /*sceneState*/)
+{
+}
+
+void AbstractView::updateImport3DSupport(const QVariantMap & /*supportMap*/)
+{
+}
+
+void AbstractView::modelNodePreviewPixmapChanged(const ModelNode & /*node*/, const QPixmap & /*pixmap*/)
+{
+}
+
+void AbstractView::dragStarted(QMimeData * /*mimeData*/) {}
+void AbstractView::dragEnded() {}
+
 QList<ModelNode> AbstractView::toModelNodeList(const QList<Internal::InternalNode::Pointer> &nodeList) const
 {
     return QmlDesigner::toModelNodeList(nodeList, const_cast<AbstractView*>(this));
@@ -373,7 +409,7 @@ QList<ModelNode> AbstractView::toModelNodeList(const QList<Internal::InternalNod
 QList<ModelNode> toModelNodeList(const QList<Internal::InternalNode::Pointer> &nodeList, AbstractView *view)
 {
     QList<ModelNode> newNodeList;
-    foreach (const Internal::InternalNode::Pointer &node, nodeList)
+    for (const Internal::InternalNode::Pointer &node : nodeList)
         newNodeList.append(ModelNode(node, view->model(), view));
 
     return newNodeList;
@@ -382,7 +418,7 @@ QList<ModelNode> toModelNodeList(const QList<Internal::InternalNode::Pointer> &n
 QList<Internal::InternalNode::Pointer> toInternalNodeList(const QList<ModelNode> &nodeList)
 {
     QList<Internal::InternalNode::Pointer> newNodeList;
-    foreach (const ModelNode &node, nodeList)
+    for (const ModelNode &node : nodeList)
         newNodeList.append(node.internalNode());
 
     return newNodeList;
@@ -390,15 +426,26 @@ QList<Internal::InternalNode::Pointer> toInternalNodeList(const QList<ModelNode>
 
 /*!
     Sets the list of nodes to the actual selected nodes specified by
-    \a selectedNodeList.
+    \a selectedNodeList if the node or its ancestors are not locked.
 */
 void AbstractView::setSelectedModelNodes(const QList<ModelNode> &selectedNodeList)
 {
-    model()->d->setSelectedNodes(toInternalNodeList(selectedNodeList));
+    QList<ModelNode> unlockedNodes;
+
+    for (const auto &modelNode : selectedNodeList) {
+        if (!ModelNode::isThisOrAncestorLocked(modelNode))
+            unlockedNodes.push_back(modelNode);
+    }
+
+    model()->d->setSelectedNodes(toInternalNodeList(unlockedNodes));
 }
 
 void AbstractView::setSelectedModelNode(const ModelNode &modelNode)
 {
+    if (ModelNode::isThisOrAncestorLocked(modelNode)) {
+        clearSelectedModelNodes();
+        return;
+    }
     setSelectedModelNodes({modelNode});
 }
 
@@ -474,44 +521,7 @@ ModelNode AbstractView::modelNodeForId(const QString &id)
 
 bool AbstractView::hasId(const QString &id) const
 {
-    return model()->d->hasId(id);
-}
-
-QString firstCharToLower(const QString &string)
-{
-    QString resultString = string;
-
-    if (!resultString.isEmpty())
-        resultString[0] = resultString.at(0).toLower();
-
-    return resultString;
-}
-
-QString AbstractView::generateNewId(const QString &prefixName) const
-{
-    QString fixedPrefix = firstCharToLower(prefixName);
-    fixedPrefix.remove(' ');
-    if (!ModelNode::isValidId(fixedPrefix))
-        return generateNewId("element");
-    int counter = 1;
-
-    /* First try just the prefixName without number as postfix, then continue with 2 and further as postfix
-     * until id does not already exist.
-     * Properties of the root node are not allowed for ids, because they are available in the complete context
-     * without qualification.
-     * The id "item" is explicitly not allowed, because it is too likely to clash.
-    */
-
-    QString newId = QString(QStringLiteral("%1")).arg(firstCharToLower(prefixName));
-    newId.remove(QRegExp(QStringLiteral("[^a-zA-Z0-9_]")));
-
-    while (!ModelNode::isValidId(newId) || hasId(newId) || rootModelNode().hasProperty(newId.toUtf8()) || newId == "item") {
-        counter += 1;
-        newId = QString(QStringLiteral("%1%2")).arg(firstCharToLower(prefixName)).arg(counter - 1);
-        newId.remove(QRegExp(QStringLiteral("[^a-zA-Z0-9_]")));
-    }
-
-    return newId;
+    return model()->hasId(id);
 }
 
 ModelNode AbstractView::modelNodeForInternalId(qint32 internalId) const
@@ -577,16 +587,24 @@ void AbstractView::enableWidget()
         widgetInfo().widget->setEnabled(true);
 }
 
-void AbstractView::contextHelpId(const Core::IContext::HelpIdCallback &callback) const
+void AbstractView::contextHelp(const Core::IContext::HelpCallback &callback) const
 {
 #ifndef QMLDESIGNER_TEST
-    QmlDesignerPlugin::instance()->viewManager().qmlJSEditorHelpId(callback);
+
+    const QString id = const_cast<AbstractView *>(this)->widgetInfo().uniqueId;
+
+    QString nodeId;
+    if (!selectedModelNodes().isEmpty())
+        nodeId = selectedModelNodes().first().simplifiedTypeName();
+    QmlDesignerPlugin::instance()->emitUsageStatisticsHelpRequested(id + " " + nodeId);
+    QmlDesignerPlugin::instance()->viewManager().qmlJSEditorContextHelp(callback);
+
 #else
     callback(QString());
 #endif
 }
 
-void AbstractView::activateTimeline(const ModelNode &timeline)
+void AbstractView::setCurrentTimeline(const ModelNode &timeline)
 {
     if (currentTimeline().isValid())
         currentTimeline().toogleRecording(false);
@@ -617,11 +635,46 @@ void AbstractView::deactivateTimelineRecording()
         model()->d->notifyCurrentTimelineChanged(ModelNode());
 }
 
+bool AbstractView::executeInTransaction(const QByteArray &identifier, const AbstractView::OperationBlock &lambda)
+{
+    try {
+        RewriterTransaction transaction = beginRewriterTransaction(identifier);
+        lambda();
+        transaction.commit();
+    } catch (const Exception &e) {
+        e.showException();
+        return false;
+    }
+
+    return true;
+}
+
+bool AbstractView::isEnabled() const
+{
+    return m_enabled;
+}
+
+void AbstractView::setEnabled(bool b)
+{
+    m_enabled = b;
+
+    if (model())
+        model()->d->updateEnabledViews();
+}
+
 QList<ModelNode> AbstractView::allModelNodes() const
 {
+    QTC_ASSERT(model(), return {});
     return toModelNodeList(model()->d->allNodes());
 }
 
+QList<ModelNode> AbstractView::allModelNodesOfType(const TypeName &typeName) const
+{
+    return Utils::filtered(allModelNodes(), [typeName](const ModelNode &node){
+        return node.metaInfo().isValid() && node.metaInfo().isSubclassOf(typeName);
+    });
+}
+
 void AbstractView::emitDocumentMessage(const QString &error)
 {
     emitDocumentMessage({DocumentMessage(error)});
@@ -708,6 +761,30 @@ void AbstractView::emitInstanceToken(const QString &token, int number, const QVe
         model()->d->notifyInstanceToken(token, number, nodeVector);
 }
 
+void AbstractView::emitRenderImage3DChanged(const QImage &image)
+{
+    if (model())
+        model()->d->notifyRenderImage3DChanged(image);
+}
+
+void AbstractView::emitUpdateActiveScene3D(const QVariantMap &sceneState)
+{
+    if (model())
+        model()->d->notifyUpdateActiveScene3D(sceneState);
+}
+
+void AbstractView::emitModelNodelPreviewPixmapChanged(const ModelNode &node, const QPixmap &pixmap)
+{
+    if (model())
+        model()->d->notifyModelNodePreviewPixmapChanged(node, pixmap);
+}
+
+void AbstractView::emitImport3DSupportChanged(const QVariantMap &supportMap)
+{
+    if (model())
+        model()->d->notifyImport3DSupportChanged(supportMap);
+}
+
 void AbstractView::emitRewriterEndTransaction()
 {
     if (model())
@@ -784,8 +861,10 @@ static int getMajorVersionFromImport(const Model *model)
 static int getMajorVersionFromNode(const ModelNode &modelNode)
 {
     if (modelNode.metaInfo().isValid()) {
-        foreach (const NodeMetaInfo &info,  modelNode.metaInfo().classHierarchy()) {
-            if (info.typeName() == "QtQuick.QtObject" || info.typeName() == "QtQuick.Item")
+        for (const NodeMetaInfo &info :  modelNode.metaInfo().classHierarchy()) {
+            if (info.typeName() == "QtQml.QtObject"
+                    || info.typeName() == "QtQuick.QtObject"
+                    || info.typeName() == "QtQuick.Item")
                 return info.majorVersion();
         }
     }
